bodhi.client.bindings — bodhi 3.1.0 documentation

# bodhi.client.bindings

This module provides Python bindings to the Bodhi REST API.

Functions

`errorhandled`(method) | A decorator for BodhiClient that raises exceptions on failure.
`input` | raw_input([prompt]) -> string

Classes

`BodhiClient`([base_url, username, password, ...]) |
`ConfigParser`([defaults, dict_type]) |
`OpenIdBaseClient`(base_url[, login_url, ...]) | A client for interacting with web services relying on openid auth.

Exceptions

`AuthError` | Error during authentication.
`BodhiClientException` |
`FedoraClientError` | Base Exception for problems which originate within the Clients.
`UpdateNotFound`(update) |

`bodhi.client.bindings.` `errorhandled`(method)

  A decorator for BodhiClient that raises exceptions on failure.